@@ -15,25 +15,22 @@ class SqlDatabase(object):
     """SqlDatabase main class for storing the candlestick data in SQL."""
 
     __slots__ = (
-        '_databasefile',
         '_conn',
         '_cursor',
-        '_encoding',
-        '_synchronous',
-        '_journal',
-        '_table',
+        '_pragmas',
+        '_schema',
     )
 
     def __init__(self: Sql, databasefile: str) -> None:
         """Database init."""
-        self._databasefile = databasefile
-        self._conn = sqlite3.connect(self._databasefile)
+        self._conn = sqlite3.connect(databasefile)
         self._cursor = self._conn.cursor()
-        self._encoding = self._cursor.execute("PRAGMA encoding='UTF-8';")
-        self._synchronous = self._cursor.execute('PRAGMA synchronous=0;')
-        self._journal = self._cursor.execute('PRAGMA journal_mode=WAL;')
-        self._table = self._cursor.execute(
-            """CREATE TABLE IF NOT EXISTS "Candlestick"(
+        self._pragmas = (
+            "PRAGMA encoding='UTF-8';",
+            'PRAGMA synchronous=0;',
+            'PRAGMA journal_mode=WAL;',
+        )
+        self._schema = """CREATE TABLE IF NOT EXISTS "Candlestick"(
                 ID INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
                 Timestamp REAL NOT NULL,
                 Open REAL NOT NULL,
@@ -43,8 +40,10 @@ class SqlDatabase(object):
                 Volume REAL NOT NULL,
                 Ticker TEXT NOT NULL,
                 Interval TEXT NOT NULL
-                )""",
-        )
+                )"""
+        for pragma in self._pragmas:
+            self._cursor.execute(pragma)
+        self._cursor.execute(self._schema)
 
     def __repr__(self: Sql) -> str:
         """Database repr."""
@@ -87,5 +86,8 @@ class SqlDatabase(object):
                         },
                     )
         except (sqlite3.Error) as sqlite_error:
-            click.echo(('Failed to write data to Database', sqlite_error))
+            click.secho(
+                f'Failed to write data to Database {sqlite_error}',
+                fg='red',
+            )
             raise
