@@ -13,6 +13,47 @@ from crypto_candlesticks.symbols.quote_currency import quote_currency
 click.secho('Welcome, what data do you wish to download?', fg='green')
 
 
+def time_clamp() -> int:
+    """Get current time in milliseconds.
+
+    Returns:
+        int: Current time in milliseconds
+    """
+    return int(round(time.time() * 1000))
+
+
+def fix_time() -> float:
+    """Fix time to a specific period."""
+    return (
+        time.mktime(
+            datetime(
+                datetime.today().year,
+                datetime.today().month,
+                datetime.today().day,
+                8,
+                0,
+            ).timetuple(),
+        )
+        * 1000
+    )
+
+
+def make_time(date: datetime) -> float:
+    """Make time in milliseconds."""
+    return (
+        time.mktime(
+            datetime(
+                date.year,
+                date.month,
+                date.day,
+                8,
+                0,
+            ).timetuple(),
+        )
+        * 1000
+    )
+
+
 @click.command()
 @click.option(
     '-s',
@@ -24,14 +65,14 @@ click.secho('Welcome, what data do you wish to download?', fg='green')
 @click.option(
     '-b',
     '--base_currency',
-    type=click.Choice((quote_currency), case_sensitive=False),
+    type=click.Choice(quote_currency, case_sensitive=False),
     prompt='Base pair',
     help='Cryptocurrency base trading pair',
 )
 @click.option(
     '-i',
     '--interval',
-    type=click.Choice((intervals), case_sensitive=True),
+    type=click.Choice(intervals, case_sensitive=True),
     prompt='Interval to download the candlestick data',
     help='Interval that will be used to download the data.',
 )
@@ -68,62 +109,23 @@ def main(
         start_date (datetime): Ending date.
         end_date (datetime): Ticker Interval.
     """
-    symbol = symbol.upper()
-    base_currency = base_currency.upper()
-    time_start = (
-        time.mktime(
-            datetime(
-                start_date.year,
-                start_date.month,
-                start_date.day,
-                8,
-                0,
-            ).timetuple(),
-        )
-        * 1000
+    one_day: int = 86400000
+
+    time_start: float = (
+        make_time(start_date)
+        if make_time(start_date) < time_clamp()
+        else fix_time()
     )
-    if time_start > min(time_start, int(round(time.time() * 1000))):
-        time_start = (
-            time.mktime(
-                datetime(
-                    datetime.today().year,
-                    datetime.today().month,
-                    datetime.today().day,
-                    8,
-                    0,
-                ).timetuple(),
-            )
-            * 1000
-        )
-    time_stop = (
-        time.mktime(
-            datetime(
-                end_date.year,
-                end_date.month,
-                end_date.day,
-                8,
-                0,
-            ).timetuple(),
-        )
-        * 1000
+
+    time_stop: float = (
+        make_time(end_date)
+        if make_time(end_date) < time_clamp()
+        else fix_time() - one_day
     )
-    if time_stop > min(time_stop, int(round(time.time() * 1000))):
-        time_stop = (
-            time.mktime(
-                datetime(
-                    datetime.today().year,
-                    datetime.today().month,
-                    datetime.today().day,
-                    8,
-                    0,
-                ).timetuple(),
-            )
-            * 1000
-        ) - 86400000
 
     get_data(
-        symbol,
-        base_currency,
+        symbol.upper(),
+        base_currency.upper(),
         time_start,
         time_stop,
         interval,
