@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 """List of current available base pairs in Bitfinex."""
+from typing import List
 
-quote_currency = [
+quote_currency: List[str] = [
     'USD',
-    'USDT',
+    'UST',
     'EUR',
     'CNHT',
     'GBP',
